nova-trame
==========

`nova-trame` is a Python package for streamlining development of Trame applications used in the NOVA framework.

You can install this package directly with

```commandline
pip install nova-trame
```

Once installed, you can check that it's working by running the widget gallery we use for visually testing components available through NOVA and Trame. We use [Pixi](https://pixi.sh/latest/) internally and recommend it for running the gallery.

```commandline
pixi install
pixi run app
```

A user guide, examples, and a full API for this package can be found at [https://nova-application-development.readthedocs.io/en/stable/](https://nova-application-development.readthedocs.io/projects/nova-trame/en/stable/).

Developers: please read [this document](DEVELOPMENT.md)
